package net.rutles.musicplayer;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.graphics.Color;
import android.media.MediaPlayer;
import android.os.Bundle;
import android.os.Environment;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ArrayAdapter;
import android.widget.ImageButton;
import android.widget.ListView;

public class MusicPlayer extends Activity 
	implements
	OnClickListener,
	OnItemClickListener,
	DialogInterface.OnClickListener{
	
	MediaPlayer mp;
	ListView listView;
	ImageButton b_previous, b_rew, b_pause, b_play, b_ff, b_next;
	String[] musicList;
	String musicPath;
	int select = 0;
	
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		
		mp = new MediaPlayer();
		if(mp == null){
			myAlert(getResources().getString(R.string.error_mp));
			return;
		}		

		if(!sdcardReadReady()){
			myAlert(getResources().getString(R.string.error_sd));
			return;
		}
		
		String rootDir = Environment.getExternalStorageDirectory().getPath();
		File musicDir = new File(rootDir + "/Music");

		if(!musicDir.exists()){
			myAlert(getResources().getString(R.string.error_file));
			return;
		}

		musicPath = musicDir.getPath() + "/";
		musicList = musicDir.list();

		List<String> tmp = new ArrayList<String>();
		for(String s: musicList){
			if(s.endsWith("MP3") || s.endsWith("mp3")){
				tmp.add(s);
			}
		}
		tmp.toArray(musicList);

		listView = (ListView) findViewById(R.id.ListView01);
		listView.setAdapter(new ArrayAdapter<String>(
			this,
			android.R.layout.simple_list_item_1,
			musicList)
		);
		
		listView.setOnItemClickListener(this);

		b_previous = (ImageButton) findViewById(R.id.ImageButton01);
		b_rew = (ImageButton) findViewById(R.id.ImageButton02);
		b_pause = (ImageButton) findViewById(R.id.ImageButton03);
		b_play = (ImageButton) findViewById(R.id.ImageButton04);
		b_ff = (ImageButton) findViewById(R.id.ImageButton05);
		b_next = (ImageButton) findViewById(R.id.ImageButton06);

		b_previous.setOnClickListener(this);
		b_rew.setOnClickListener(this);
		b_pause.setOnClickListener(this);
		b_play.setOnClickListener(this);
		b_ff.setOnClickListener(this);
		b_next.setOnClickListener(this);
	}

	@Override
	public void onItemClick(AdapterView<?> arg0, View arg1, int arg2, long arg3) {
		// TODO Auto-generated method stub
		if(arg0 == listView){
		selectMusic(arg2);
		}
	}

	private void selectMusic(int newSelect){
		listView.getChildAt(select).setBackgroundColor(android.R.color.background_dark);
		listView.getChildAt(newSelect).setBackgroundColor(Color.GREEN);
		select = newSelect;
		mp.stop();
		mp.reset();
		try{
		mp.setDataSource(musicPath + musicList[select]);
		mp.prepare();
		}catch(Exception e){}
		mp.start();
	}
	
	private boolean sdcardReadReady(){
		String state = Environment.getExternalStorageState();
		return (
		Environment.MEDIA_MOUNTED.equals(state) || 
		Environment
		.MEDIA_MOUNTED_READ_ONLY.equals(state)
		);
	}

	private void myAlert(String message){
		new AlertDialog.Builder(this)
		.setTitle(R.string.app_name)
		.setMessage(message)
		.setNeutralButton("OK", this)
		.show();
	}

	@Override
	public void onClick(View v) {
		// TODO Auto-generated method stub
		if(v == b_previous){
			if(select == 0) selectMusic(musicList.length - 1);
			else selectMusic(select - 1);
		}else
		if(v == b_rew){
			mp.seekTo(mp.getCurrentPosition() - 3000);			
		} else
		if(v == b_pause){
			mp.pause();
		}else
		if(v == b_play){
			mp.start();
		}else
		if(v == b_ff){
			mp.seekTo(mp.getCurrentPosition() + 3000);			
		}else
		if(v == b_next){
			if(select == (musicList.length -1)) selectMusic(0);
			else selectMusic(select +1);
		}
	}

	@Override
	public void onClick(DialogInterface arg0, int arg1) {
		// TODO Auto-generated method stub
		if(arg1==DialogInterface.BUTTON_NEUTRAL){
			arg0.dismiss();
			finish();
		}
	}

	protected void onPause() {
		super.onPause();
		mp.stop();
	}

	protected void onDestroy() {
		super.onDestroy();
		mp.release();
	}
}